diff --git a/libraries/tbl_properties.inc.php b/libraries/tbl_properties.inc.php
index ae287f8608..3cbf3eadbd 100644
--- a/libraries/tbl_properties.inc.php
+++ b/libraries/tbl_properties.inc.php
@@ -669,8 +669,8 @@ if ($action == 'tbl_create.php') {
diff --git a/tbl_create.php b/tbl_create.php
index 55d76ba9a6..ca4b41182b 100644
--- a/tbl_create.php
+++ b/tbl_create.php
@@ -186,8 +186,8 @@ if (isset($_REQUEST['do_save_data'])) {
. ' (' . $sql_query . ')';
// Adds table type, character set, comments and partition definition
- if (!empty($_REQUEST['tbl_type']) && ($_REQUEST['tbl_type'] != 'Default')) {
- $sql_query .= ' ENGINE = ' . $_REQUEST['tbl_type'];
+ if (!empty($_REQUEST['tbl_storage_engine']) && ($_REQUEST['tbl_storage_engine'] != 'Default')) {
+ $sql_query .= ' ENGINE = ' . $_REQUEST['tbl_storage_engine'];
}
if (!empty($_REQUEST['tbl_collation'])) {
$sql_query .= PMA_generateCharsetQueryPart($_REQUEST['tbl_collation']);
diff --git a/tbl_operations.php b/tbl_operations.php
index 61e25c4298..27c3edd6c2 100644
--- a/tbl_operations.php
+++ b/tbl_operations.php
@@ -52,7 +52,7 @@ require 'libraries/tbl_info.inc.php';
// define some globals here, for improved syntax in the conditionals
$is_myisam_or_aria = $is_isam = $is_innodb = $is_berkeleydb = $is_aria = $is_pbxt = false;
// set initial value of these globals, based on the current table engine
-PMA_set_global_variables_for_engine($tbl_type);
+PMA_set_global_variables_for_engine($tbl_storage_engine);
if ($is_aria) {
// the value for transactional can be implicit
@@ -104,12 +104,12 @@ if (isset($_REQUEST['submitoptions'])) {
&& urldecode($_REQUEST['prev_comment']) !== $_REQUEST['comment']) {
$table_alters[] = 'COMMENT = \'' . PMA_sqlAddSlashes($_REQUEST['comment']) . '\'';
}
- if (! empty($_REQUEST['new_tbl_type'])
- && strtolower($_REQUEST['new_tbl_type']) !== strtolower($tbl_type)) {
- $table_alters[] = 'ENGINE = ' . $_REQUEST['new_tbl_type'];
- $tbl_type = $_REQUEST['new_tbl_type'];
+ if (! empty($_REQUEST['new_tbl_storage_engine'])
+ && strtolower($_REQUEST['new_tbl_storage_engine']) !== strtolower($tbl_storage_engine)) {
+ $table_alters[] = 'ENGINE = ' . $_REQUEST['new_tbl_storage_engine'];
+ $tbl_storage_engine = $_REQUEST['new_tbl_storage_engine'];
// reset the globals for the new engine
- PMA_set_global_variables_for_engine($tbl_type);
+ PMA_set_global_variables_for_engine($tbl_storage_engine);
if ($is_aria) {
$transactional = (isset($transactional) && $transactional == '0') ? '0' : '1';
$page_checksum = (isset($page_checksum)) ? $page_checksum : '';
@@ -178,7 +178,7 @@ if (isset($_REQUEST['submitoptions'])) {
// should not be reported with a Level of Error, so here
// I just ignore it. But there are other 1478 messages
// that it's better to show.
- if (! ($_REQUEST['new_tbl_type'] == 'MyISAM' && $warning['Code'] == '1478' && $warning['Level'] == 'Error')) {
+ if (! ($_REQUEST['new_tbl_storage_engine'] == 'MyISAM' && $warning['Code'] == '1478' && $warning['Level'] == 'Error')) {
$warning_messages[] = $warning['Level'] . ': #' . $warning['Code']
. ' ' . $warning['Message'];
}
@@ -374,7 +374,7 @@ if (strstr($show_comment, '; InnoDB free') === false) {
-
+
@@ -509,11 +509,11 @@ unset($innodb_engine_plugin, $innodb_plugin_version, $innodb_file_format);
// does not return a warning
// (if the table was compressed, it can be seen on the Structure page)
-if (isset($possible_row_formats[$tbl_type])) {
+if (isset($possible_row_formats[$tbl_storage_engine])) {
$current_row_format = strtoupper($showtable['Row_format']);
echo '
diff --git a/libraries/tbl_info.inc.php b/libraries/tbl_info.inc.php
index 4c126719ae..6d520bd553 100644
--- a/libraries/tbl_info.inc.php
+++ b/libraries/tbl_info.inc.php
@@ -24,7 +24,7 @@ PMA_checkParameters(array('db', 'table'));
* Defining global variables, in case this script is included by a function.
* This is necessary because this script can be included by libraries/header.inc.php.
*/
-global $showtable, $tbl_is_view, $tbl_type, $show_comment, $tbl_collation,
+global $showtable, $tbl_is_view, $tbl_storage_engine, $show_comment, $tbl_collation,
$table_info_num_rows, $auto_increment;
/**
@@ -52,16 +52,16 @@ $GLOBALS['showtable'] = PMA_Table::sGetStatusInfo($GLOBALS['db'], $GLOBALS['tabl
// need this test because when we are creating a table, we get 0 rows
// from the SHOW TABLE query
// and we don't want to mess up the $tbl_type coming from the form
if ($showtable) {
if (PMA_Table::isView($GLOBALS['db'], $GLOBALS['table'])) {
$tbl_is_view = true;
- $tbl_type = __('View');
+ $tbl_storage_engine = __('View');
$show_comment = null;
} else {
$tbl_is_view = false;
- $tbl_type = isset($showtable['Engine'])
+ $tbl_storage_engine = isset($showtable['Engine'])
? strtoupper($showtable['Engine'])
: '';
// a new comment could be coming from tbl_operations.php
@@ -52,16 +52,16 @@ $GLOBALS['showtable'] = PMA_Table::sGetStatusInfo($GLOBALS['db'], $GLOBALS['tabl
// need this test because when we are creating a table, we get 0 rows
// from the SHOW TABLE query
-// and we don't want to mess up the $tbl_type coming from the form
+// and we don't want to mess up the $tbl_storage_engine coming from the form
if ($showtable) {
if (PMA_Table::isView($GLOBALS['db'], $GLOBALS['table'])) {